@@ -29,14 +29,14 @@ module load charliecloud
 
 # MPI version on host.
 printf 'host:      '
-mpirun --version | egrep '^mpirun'
+mpirun --version | grep -E '^mpirun'
 
 # Unpack image.
-srun ch-tar2dir $TAR $IMGDIR
+srun ch-tar2dir "$TAR" "$IMGDIR"
 
 # MPI version in container.
 printf 'container: '
-ch-run $IMG -- mpirun --version | egrep '^mpirun'
+ch-run "$IMG" -- mpirun --version | grep -E '^mpirun'
 
 # Run the app.
-srun --cpus-per-task=1 ch-run $IMG -- /hello/hello
+srun --cpus-per-task=1 ch-run "$IMG" -- /hello/hello
